@@ -3,7 +3,7 @@ Type defs for data operations.
 """
 
 import abc
-from typing import Dict, List, Optional, Set, NamedTuple
+from typing import Any, Dict, Iterable, List, Optional, Set, NamedTuple
 
 import data_algebra.expr_rep
 import data_algebra.cdata
@@ -31,19 +31,17 @@ class OperatorPlatform(abc.ABC):
     @abc.abstractmethod
     def eval(
         self,
-        data_map,
+        data_map: Dict[str, Any],
         *,
-        data_model=None,
-        narrow: bool = True,
-        check_incoming_data_constraints: bool = False
+        data_model = None,
+        narrow: bool = True
     ):
         """
         Evaluate operators with respect to Pandas data frames.
 
-        :param data_map: map from table names to data frames
+        :param data_map: map from table names to data frames or data sources
         :param data_model: adaptor to data dialect (Pandas for now)
         :param narrow: logical, if True don't copy unexpected columns
-        :param check_incoming_data_constraints: logical, if True check incoming data meets constraints
         :return: table result
         """
 
@@ -54,8 +52,7 @@ class OperatorPlatform(abc.ABC):
         X,
         *,
         data_model=None,
-        narrow: bool = True,
-        check_incoming_data_constraints: bool = False
+        narrow: bool = True
     ):
         """
         apply self to data frame X, may or may not commute with composition
@@ -63,7 +60,6 @@ class OperatorPlatform(abc.ABC):
         :param X: input data frame
         :param data_model: implementation to use
         :param narrow: logical, if True don't copy unexpected columns
-        :param check_incoming_data_constraints: logical, if True check incoming data meets constraints
         :return: transformed data frame
         """
 
@@ -79,55 +75,19 @@ class OperatorPlatform(abc.ABC):
         return self.transform(
             X=X,
             data_model=data_model,
-            narrow=False,
-            check_incoming_data_constraints=True,
+            narrow=False
         )
 
     @abc.abstractmethod
-    def apply_to(self, a, *, target_table_key=None):
+    def replace_leaves(self, replacement_map: Dict[str, Any]):
         """
-        apply self to operator DAG a
+        Replace leaves of DAG
 
         :param a: operators to apply to
-        :param target_table_key: table key to replace with self, None counts as "match all"
+        :param replacement_map, table/sqlkeys mapped to replacement Operator platforms
         :return: new operator DAG
         """
 
-    def __rrshift__(self, other):  # override other >> self
-        """
-        override other >> self
-        self.apply_to/act_on(other)
-
-        :param other:
-        :return:
-        """
-        if isinstance(other, OperatorPlatform):
-            return self.apply_to(other)
-        return self.act_on(other)
-
-    def __rshift__(self, other):  # override self >> other
-        """
-        override self >> other
-        other.apply_to(self)
-
-        :param other:
-        :return:
-        """
-        # can't use type >> type if only __rrshift__ is defined (must have __rshift__ in this case)
-        if isinstance(other, OperatorPlatform):
-            return other.apply_to(self)
-        raise TypeError("unexpected type: " + str(type(other)))
-
-    # composition
-    def add(self, other):
-        """
-        other.apply_to(self)
-
-        :param other:
-        :return:
-        """
-        return other.apply_to(self)
-
     # imitate a method
     def use(self, user_function, *args, **kwargs):
         """
@@ -249,14 +209,25 @@ class OperatorPlatform(abc.ABC):
         """
 
     @abc.abstractmethod
-    def natural_join(self, b, *, by, jointype, check_all_common_keys_in_by=False):
+    def natural_join(
+        self,
+        b,
+        *,
+        on: Optional[Iterable[str]] = None,
+        jointype: str,
+        check_all_common_keys_in_equi_spec: bool = False,
+        by: Optional[Iterable[str]] = None,
+        check_all_common_keys_in_by: bool = False
+    ):
         """
         Join self (left) results with b (right).
 
         :param b: second or right table to join to.
-        :param by: list of join key column names.
+        :param on: list of join column names to enforce equality on.
         :param jointype: name of join type.
-        :param check_all_common_keys_in_by: if True, raise if any non-key columns are common to tables.
+        :param check_all_common_keys_in_equi_spec: if True, raise if any non-equality key columns are common to tables.
+        :param by: synonym for on, only set at most one of on or by (deprecated).
+        :param check_all_common_keys_in_by: synonym for check_all_common_keys_in_equi_spec (deprecated).
         :return: compose operator directed acyclic graph
         """
 
@@ -299,6 +270,16 @@ class OperatorPlatform(abc.ABC):
         :return: compose operator directed acyclic graph
         """
 
+    @abc.abstractmethod
+    def map_columns(self, column_remapping: Dict[str, str]):
+        """
+        Map column names or rename.
+
+        :param column_remapping: dictionary mapping old column sources to new column names (same
+                                 direction as Pandas rename).
+        :return: compose operator directed acyclic graph
+        """
+
     @abc.abstractmethod
     def rename_columns(self, column_remapping: Dict[str, str]):
         """
@@ -367,7 +348,7 @@ class OperatorPlatform(abc.ABC):
             cp = cp + [f for f in input_features if f not in cp_set]
         return cp
 
-    # noinspection PyUnusedLocal,PyMethodMayBeStatic
+    # noinspection PyMethodMayBeStatic
     def get_params(self, deep=False):
         """sklearn interface, noop"""
         return dict()
