@@ -712,25 +712,37 @@ def _annotated_method_catalogue(
         if row["op_class"] in {"p", "up"}:
             matches.append(
                 data_algebra.data_ops_types.MethodUse(
-                    row["op"], is_project=True, is_windowed=False, is_ordered=False,
+                    row["op"],
+                    is_project=True,
+                    is_windowed=False,
+                    is_ordered=False,
                 )
             )
         elif row["op_class"] == "g":
             matches.append(
                 data_algebra.data_ops_types.MethodUse(
-                    row["op"], is_project=False, is_windowed=True, is_ordered=False,
+                    row["op"],
+                    is_project=False,
+                    is_windowed=True,
+                    is_ordered=False,
                 )
             )
         elif row["op_class"] == "w":
             matches.append(
                 data_algebra.data_ops_types.MethodUse(
-                    row["op"], is_project=False, is_windowed=True, is_ordered=True,
+                    row["op"],
+                    is_project=False,
+                    is_windowed=True,
+                    is_ordered=True,
                 )
             )
         else:  # e and u case
             matches.append(
                 data_algebra.data_ops_types.MethodUse(
-                    row["op"], is_project=False, is_windowed=False, is_ordered=False,
+                    row["op"],
+                    is_project=False,
+                    is_windowed=False,
+                    is_ordered=False,
                 )
             )
         if len(matches) > 0:
@@ -745,8 +757,7 @@ def _annotated_method_catalogue(
 
 
 class DBModel:
-    """A model of how SQL should be generated for a given database.
-       """
+    """A model of how SQL should be generated for a given database."""
 
     identifier_quote: str
     string_quote: str
@@ -1508,6 +1519,51 @@ class DBModel:
         )
         return near_sql
 
+    def map_columns_to_near_sql(
+        self,
+        map_columns_node,
+        *,
+        using=None,
+        temp_id_source=None,
+        sql_format_options=None,
+    ) -> data_algebra.near_sql.NearSQL:
+        """
+        Convert map columns columns to NearSQL.
+        """
+        if map_columns_node.node_name != "MapColumnsNode":
+            raise TypeError(
+                "Expected map_columns_node to be a data_algebra.data_ops.MapColumnsNode)"
+            )
+        if temp_id_source is None:
+            temp_id_source = [0]
+        if using is None:
+            using = OrderedSet(map_columns_node.column_names)
+        subusing = map_columns_node.columns_used_from_sources(using=using)[0]
+        subsql = map_columns_node.sources[0].to_near_sql_implementation_(
+            db_model=self, using=subusing, temp_id_source=temp_id_source
+        )
+        view_name = "map_columns_" + str(temp_id_source[0])
+        temp_id_source[0] = temp_id_source[0] + 1
+        unchanged_columns = subusing - (
+            set(map_columns_node.column_remapping.values()).union(map_columns_node.column_remapping.keys()).union(map_columns_node.column_deletions))
+        terms = {
+            ki: self.quote_identifier(vi)
+            for (vi, ki) in map_columns_node.column_remapping.items()
+            if (vi is not None) and (ki is not None)
+        }
+        terms.update({vi: None for vi in unchanged_columns})
+        near_sql = data_algebra.near_sql.NearSQLUnaryStep(
+            terms=terms,
+            query_name=view_name,
+            quoted_query_name=self.quote_identifier(view_name),
+            sub_sql=subsql.to_bound_near_sql(columns=subusing),
+            annotation=str(
+                map_columns_node.to_python_src_(print_sources=False, indent=-1)
+            ),
+            ops_key=f"map_columns({map_columns_node}, {terms.keys()})",
+        )
+        return near_sql
+
     def rename_to_near_sql(
         self, rename_node, *, using=None, temp_id_source=None, sql_format_options=None
     ) -> data_algebra.near_sql.NearSQL:
@@ -1528,9 +1584,8 @@ class DBModel:
         )
         view_name = "rename_" + str(temp_id_source[0])
         temp_id_source[0] = temp_id_source[0] + 1
-        unchanged_columns = subusing - set(rename_node.column_remapping.values()).union(
-            rename_node.column_remapping.keys()
-        )
+        unchanged_columns = subusing - (
+            set(rename_node.column_remapping.values()).union(rename_node.column_remapping.keys()))
         terms = {
             ki: self.quote_identifier(vi)
             for (ki, vi) in rename_node.column_remapping.items()
@@ -1586,14 +1641,13 @@ class DBModel:
             )
         if using is None:
             using = OrderedSet(join_node.column_names)
-        by_set = OrderedSet(join_node.by)
         if len(using) < 1:
             raise ValueError("join must use or select at least one column")
         missing = using - set(join_node.column_names)
         if len(missing) > 0:
             raise KeyError("referred to unknown columns: " + str(missing))
         using_left, using_right = join_node.columns_used_from_sources(
-            using=using.union(by_set)
+            using=using.union(join_node.on_a).union(join_node.on_b)
         )
         sql_left = join_node.sources[0].to_near_sql_implementation_(
             db_model=self, using=using_left, temp_id_source=temp_id_source
@@ -1648,17 +1702,17 @@ class DBModel:
             if ci not in common:
                 terms[ci] = None
         on_terms = []
-        if len(join_node.by) > 0:
+        if len(join_node.on_a) > 0:
             on_terms = ["ON " + self.on_start] + self._indent_and_sep_terms(
                 [
                     left_qqn
                     + "."
-                    + self.quote_identifier(c)
+                    + self.quote_identifier(c_a)
                     + " = "
                     + right_qqn
                     + "."
-                    + self.quote_identifier(c)
-                    for c in join_node.by
+                    + self.quote_identifier(c_b)
+                    for c_a, c_b in zip(join_node.on_a, join_node.on_b)
                 ],
                 sep=self.on_joiner,
                 sql_format_options=sql_format_options,
@@ -2028,7 +2082,12 @@ class DBModel:
         return v + " AS " + self.quote_identifier(k)
 
     def nearsqlcte_to_sql_str_list_(
-        self, near_sql, *, columns=None, force_sql=False, sql_format_options=None,
+        self,
+        near_sql,
+        *,
+        columns=None,
+        force_sql=False,
+        sql_format_options=None,
     ) -> List[str]:
         """
         Convert SQL common table expression to list of SQL string lines.
@@ -2047,7 +2106,12 @@ class DBModel:
         return [near_sql.quoted_query_name]
 
     def nearsqltable_to_sql_str_list_(
-        self, near_sql, *, columns=None, force_sql=False, sql_format_options=None,
+        self,
+        near_sql,
+        *,
+        columns=None,
+        force_sql=False,
+        sql_format_options=None,
     ) -> List[str]:
         """
         Convert SQL table description to list of SQL string lines.
@@ -2078,7 +2142,12 @@ class DBModel:
         return [near_sql.quoted_table_name]
 
     def nearsqlunary_to_sql_str_list_(
-        self, near_sql, *, columns=None, force_sql=False, sql_format_options=None,
+        self,
+        near_sql,
+        *,
+        columns=None,
+        force_sql=False,
+        sql_format_options=None,
     ) -> List[str]:
         """
         Convert SQL unary operation to list of SQL string lines.
@@ -2124,7 +2193,11 @@ class DBModel:
         return sql
 
     def nearsqlrawq_to_sql_str_list_(
-        self, near_sql, *, sql_format_options=None, add_select=True,
+        self,
+        near_sql,
+        *,
+        sql_format_options=None,
+        add_select=True,
     ) -> List[str]:
         """
         Convert user SQL query to list of SQL string lines.
