@@ -3,8 +3,7 @@ Redirecting container.
 """
 
 from types import SimpleNamespace
-import typing
-from typing import Set
+from typing import Any, Dict, Iterable, List, Optional, Set
 
 import data_algebra.data_ops_types
 import data_algebra.data_ops
@@ -20,7 +19,7 @@ one = data_algebra.expr_rep.Value(1)
 class OpC(data_algebra.data_ops_types.OperatorPlatform):
     """Container that redirects to another to non-quoted notation."""
 
-    ops: typing.Optional[
+    ops: Optional[
         data_algebra.data_ops.ViewRepresentation
     ]  # this reference gets replaced
     column_namespace: SimpleNamespace  # don't replace the reference, instead mutate (reference shared!)
@@ -79,15 +78,13 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
         X,
         *,
         data_model=None,
-        narrow: bool = True,
-        check_incoming_data_constraints: bool = False
+        narrow: bool = True
     ):
         assert isinstance(self.ops, data_algebra.data_ops.ViewRepresentation)
         return self.ops.transform(
             X=X,
             data_model=data_model,
-            narrow=narrow,
-            check_incoming_data_constraints=check_incoming_data_constraints,
+            narrow=narrow
         )
 
     # noinspection PyPep8Naming
@@ -95,8 +92,8 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
         self.set(self.ops.act_on(X=X, data_model=data_model))
         return self
 
-    def apply_to(self, a, *, target_table_key=None):
-        self.set(self.ops.apply_to(a=a, target_table_key=target_table_key))
+    def replace_leaves(self, replacement_map: Dict[str, Any]):
+        self.set(self.ops.replace_leaves(replacement_map))
         return self
 
     def __rrshift__(self, other):  # override other >> self
@@ -107,7 +104,7 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
         self.set(self.ops.__rshift__(other))
         return self
 
-    def eval(self, data_map, *, data_model=None, narrow=True):
+    def eval(self, data_map: Dict[str, Any], *, data_model=None, narrow=True):
         return self.ops.eval(data_map=data_map, data_model=data_model, narrow=narrow)
 
     def get_tables(self):
@@ -125,9 +122,9 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
 
     # query generation
 
-    def to_near_sql_implementation_(self, db_model, *, using, temp_id_source):
+    def to_near_sql_implementation_(self, db_model, *, using, temp_id_source, sql_format_options=None):
         return self.ops.to_near_sql_implementation_(
-            db_model=db_model, using=using, temp_id_source=temp_id_source
+            db_model=db_model, using=using, temp_id_source=temp_id_source, sql_format_options=sql_format_options
         )
 
     # define builders for all non-initial ops types on base class
@@ -158,16 +155,41 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
         return self
 
     def project(self, ops=None, *, group_by=None):
-        self.set(self.ops.project(ops=ops, group_by=group_by,))
+        self.set(
+            self.ops.project(
+                ops=ops,
+                group_by=group_by,
+            )
+        )
         return self
 
-    def natural_join(self, b, *, by, jointype, check_all_common_keys_in_by=False):
+    def natural_join(
+        self,
+        b,
+        *,
+        on: Optional[Iterable[str]] = None,
+        jointype: str,
+        check_all_common_keys_in_equi_spec: bool = False,
+        by: Optional[Iterable[str]] = None,
+        check_all_common_keys_in_by: bool = False
+    ):
+        assert (on is None) or (by is None)
+        if by is not None:
+            on = by
+        if on is None:
+            on = []
+        elif isinstance(on, str):
+            on = [on]
+        else:
+            on = list(on)
         self.set(
             self.ops.natural_join(
                 b=b,
-                by=by,
+                on=on,
                 jointype=jointype,
-                check_all_common_keys_in_by=check_all_common_keys_in_by,
+                check_all_common_keys_in_by=(
+                    check_all_common_keys_in_equi_spec or check_all_common_keys_in_by
+                ),
             )
         )
         return self
@@ -183,7 +205,11 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
         return self
 
     def select_rows(self, expr):
-        self.set(self.ops.select_rows(expr=expr,))
+        self.set(
+            self.ops.select_rows(
+                expr=expr,
+            )
+        )
         return self
 
     def drop_columns(self, column_deletions):
@@ -194,6 +220,10 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
         self.set(self.ops.select_columns(columns=columns))
         return self
 
+    def map_columns(self, column_remapping):
+        self.set(self.ops.map_columns(column_remapping=column_remapping))
+        return self
+
     def rename_columns(self, column_remapping):
         self.set(self.ops.rename_columns(column_remapping=column_remapping))
         return self
@@ -208,7 +238,8 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
 
     def map_records(self, blocks_in=None, blocks_out=None):
         self.ops.map_records(
-            blocks_in=blocks_in, blocks_out=blocks_out,
+            blocks_in=blocks_in,
+            blocks_out=blocks_out,
         )
         return self
 
@@ -226,6 +257,12 @@ class OpC(data_algebra.data_ops_types.OperatorPlatform):
     def get_feature_names(self, input_features=None):
         return self.ops.get_feature_names(input_features=input_features)
 
+    def __str__(self) -> str:
+        return f"OpC({self.ops})"
+    
+    def __repr__(self) -> str:
+        return f"OpC({self.ops})"
+
 
 # pop 0343 context manager
 # https://www.python.org/dev/peps/pep-0343/#use-cases
