@@ -3,7 +3,7 @@ Base class for adapters for Pandas-like APIs
 """
 
 from abc import ABC
-from typing import Callable, Dict, Optional
+from typing import Any, Callable, Dict, Optional
 import datetime
 import types
 import numbers
@@ -319,10 +319,11 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
             "NaturalJoinNode": self.natural_join_step,
             "OrderRowsNode": self.order_rows_step,
             "ProjectNode": self.project_step,
+            "MapColumnsNode": self.map_columns_step,
             "RenameColumnsNode": self.rename_columns_step,
             "SelectColumnsNode": self.select_columns_step,
             "SelectRowsNode": self.select_rows_step,
-            "SQLNode": self._sql_proxy_step,
+            "SQLNode": self.sql_proxy_step,
             "TableDescription": self.table_step,
         }
 
@@ -400,7 +401,7 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
     # noinspection PyMethodMayBeStatic,PyUnusedLocal
     def table_step(self, op, *, data_map: dict, narrow: bool):
         """
-        Return data frame from table description and data_map.
+        Return a copy of data frame from table description and data_map.
         """
         if op.node_name != "TableDescription":
             raise TypeError(
@@ -428,15 +429,17 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
             raise ValueError("missing required columns: " + str(missing))
         # make an index-free copy of the data to isolate side-effects and not deal with indices
         res = df.loc[:, columns_using]
-        res = res.reset_index(drop=True, inplace=False)  # copy
+        res = res.reset_index(drop=True, inplace=False)  # copy and clear out indices
         return res
 
-    def _sql_proxy_step(self, op, *, data_map: dict, narrow: bool):
+    def sql_proxy_step(self, op, *, data_map: dict, narrow: bool):
         """
-        replace user sql with view from data map
+        execute SQL
         """
         assert op.node_name == "SQLNode"
-        return data_map[op.view_name].reset_index(drop=True, inplace=False)  # copy
+        db_handle = data_map[op.view_name]
+        res = db_handle.read_query("\n".join(op.sql))
+        return res
 
     def columns_to_frame_(self, cols, *, target_rows=0):
         """
@@ -518,16 +521,16 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
             res[c] = transient_new_frame[c]
         return res
 
-    def eval(self, op, *, data_map: Optional[Dict] = None, narrow: bool = False):
+    def eval(self, op, *, data_map: Dict[str, Any], narrow: bool = False):
         """
         Implementation of Pandas evaluation of operators
 
         :param op: ViewRepresentation to evaluate
-        :param data_map: dictionary mapping table and view names to data frames
+        :param data_map: dictionary mapping table and view names to data frames or data sources
         :param narrow: if True narrow results to only columns anticipated
         :return: data frame result
         """
-        assert data_map is not None  # type hint/enforcement
+        assert isinstance(data_map, Dict)
         return self._eval_value_source(s=op, data_map=data_map, narrow=narrow)
 
     def _eval_value_source(self, s, *, data_map: dict, narrow: bool):
@@ -822,6 +825,21 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
             res = res.iloc[range(op.limit), :].reset_index(drop=True)
         return res
 
+    def map_columns_step(self, op, *, data_map, narrow):
+        """
+        Execute a map columns step, returning a data frame.
+        """
+        if op.node_name != "MapColumnsNode":
+            raise TypeError(
+                "op was supposed to be a data_algebra.data_ops.MapColumnsNode"
+            )
+        res = self._eval_value_source(op.sources[0], data_map=data_map, narrow=narrow)
+        res = res.rename(columns=op.column_remapping)
+        if (op.column_deletions is not None) and (len(op.column_deletions) > 0):
+            column_selection = [c for c in res.columns if c not in op.column_deletions]
+            res = res[column_selection]
+        return res
+
     def rename_columns_step(self, op, *, data_map, narrow):
         """
         Execute a rename columns step, returning a data frame.
@@ -868,13 +886,13 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
         )
         if type_checks is not None:
             raise ValueError(f"join: incompatible column types: {type_checks}")
-        by = op.by
-        if by is None:
-            by = []
-        scratch_col = None  # extra column to prevent empty-by issues
-        if len(by) <= 0:
+        on_a = op.on_a
+        on_b = op.on_b
+        scratch_col = None  # extra column to prevent empty-on issues
+        if len(on_a) <= 0:
             scratch_col = "data_algebra_temp_merge_col"
-            by = [scratch_col]
+            on_a = [scratch_col]
+            on_b = [scratch_col]
             left[scratch_col] = 1
             right[scratch_col] = 1
         # noinspection PyUnresolvedReferences
@@ -882,15 +900,17 @@ class PandasModelBase(data_algebra.data_model.DataModel, ABC):
             left=left,
             right=right,
             how=self.standardize_join_code_(op.jointype),
-            on=by,
+            left_on=on_a,
+            right_on=on_b,
             sort=False,
             suffixes=("", "_tmp_right_col"),
         )
         res = res.reset_index(drop=True)
         if scratch_col is not None:
             del res[scratch_col]
+        on_a_set = set(op.on_a)
         for c in common_cols:
-            if c not in op.by:
+            if c not in on_a_set:
                 is_null = res[c].isnull()
                 res.loc[is_null, c] = res.loc[is_null, c + "_tmp_right_col"]
                 res = res.drop(c + "_tmp_right_col", axis=1, inplace=False)
